@@ -136,7 +136,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime - t->shift);
+		/* h= */ bsearch_node(t->n.nd, basetime - t->shift); /* scan-build */
 		hp=GLOBALS->max_compare_index;
 		if((hp==&(t->n.nd->harray[1]))||(hp==&(t->n.nd->harray[0]))) return;
 		if(basetime == ((*hp)->time+GLOBALS->shift_timebase)) hp--;
@@ -152,7 +152,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime - t->shift);
+		/* v= */ bsearch_vector(t->n.vec, basetime - t->shift); /* scan-build */
 		vp=GLOBALS->vmax_compare_index;
 		if((vp==&(t->n.vec->vectors[1]))||(vp==&(t->n.vec->vectors[0]))) return;
 		if(basetime == ((*vp)->time+GLOBALS->shift_timebase)) vp--;
@@ -506,7 +506,7 @@ service_left_edge(GtkWidget *text, gpointer data)
 {
 if(GLOBALS->helpbox_is_active)
         {
-        help_text_bold("\n\nFind Next Edge Left");
+        help_text_bold("\n\nFind Previous Edge");
         help_text(
                 " moves the marker to the closest transition to the left of the marker"
 		" of the first highlighted trace.  If the marker is not nailed down, it starts from max time."
@@ -524,7 +524,7 @@ service_right_edge(GtkWidget *text, gpointer data)
 {
 if(GLOBALS->helpbox_is_active)
         {
-        help_text_bold("\n\nFind Next Edge Right");
+        help_text_bold("\n\nFind Next Edge");
         help_text(
                 " moves the marker to the closest transition to the right of the marker"
 		" of the first highlighted trace.  If the marker is not nailed down, it starts from min time."
