@@ -606,7 +606,8 @@ if(GLOBALS->fast_tree_sort)
 		int len;
 
 		GLOBALS->facs[i]=&sym_block[i];
-	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+		subst=GLOBALS->facs[i]->name;
+	        if((len=strlen(subst))>GLOBALS->longestname) GLOBALS->longestname=len;
 #ifdef WAVE_HIERFIX
 		while((ch=(*subst)))
 			{	
@@ -922,7 +923,7 @@ if(!(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
         }
 
 	{
-        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+        struct HistEnt *htemp2 = histent_calloc();
         htemp2->time = -1;
         if(len>1)
         	{
