@@ -275,9 +275,9 @@ ghw_read_range (struct ghw_handler *h)
 	r->kind = t & 0x7f;
 	r->dir = (t & 0x80) != 0;
 	if (ghw_read_byte (h, &r->left) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	if (ghw_read_byte (h, &r->right) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	return (union ghw_range *)r;
       }
     case ghdl_rtik_type_e8:
@@ -287,9 +287,9 @@ ghw_read_range (struct ghw_handler *h)
 	r->kind = t & 0x7f;
 	r->dir = (t & 0x80) != 0;
 	if (ghw_read_byte (h, &r->left) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	if (ghw_read_byte (h, &r->right) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	return (union ghw_range *)r;
       }
     case ghdl_rtik_type_i32:
@@ -300,9 +300,9 @@ ghw_read_range (struct ghw_handler *h)
 	r->kind = t & 0x7f;
 	r->dir = (t & 0x80) != 0;
 	if (ghw_read_sleb128 (h, &r->left) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	if (ghw_read_sleb128 (h, &r->right) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	return (union ghw_range *)r;
       }
     case ghdl_rtik_type_i64:
@@ -313,9 +313,9 @@ ghw_read_range (struct ghw_handler *h)
 	r->kind = t & 0x7f;
 	r->dir = (t & 0x80) != 0;
 	if (ghw_read_lsleb128 (h, &r->left) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	if (ghw_read_lsleb128 (h, &r->right) != 0)
-	  return NULL;
+	  { free(r) ; return NULL; } /* scan-build */
 	return (union ghw_range *)r;
       }
     case ghdl_rtik_type_f64:
@@ -325,9 +325,9 @@ ghw_read_range (struct ghw_handler *h)
 	r->kind = t & 0x7f;
 	r->dir = (t & 0x80) != 0;
 	if (ghw_read_f64 (h, &r->left) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	if (ghw_read_f64 (h, &r->right) != 0)
-	  return NULL;
+	  { free(r); return NULL; } /* scan-build */
 	return (union ghw_range *)r;
       }
     default:
@@ -878,6 +878,12 @@ ghw_read_hie (struct ghw_handler *h)
       if (t == ghw_hie_eos)
 	{
 	  blk = blk->parent;
+          if(!blk) /* scan-build : possibly from malformed file? */
+		{
+		  fprintf (stderr, "ghw_read_hie: NULL pointer on ghw_hie_eos\n");
+		  abort ();
+		}
+
 	  if (blk->u.blk.child == NULL)
 	    last = &blk->u.blk.child;
 	  else
@@ -1110,7 +1116,7 @@ ghw_read_eoh (struct ghw_handler *h)
 int
 ghw_read_base (struct ghw_handler *h)
 {
-  unsigned char hdr[4];
+  unsigned char hdr[4] = { 0, 0, 0, 0 }; /* scan-build */
   int res;
 
   while (1)
@@ -1429,7 +1435,7 @@ ghw_read_tailer (struct ghw_handler *h)
 enum ghw_res
 ghw_read_sm_hdr (struct ghw_handler *h, int *list)
 {
-  unsigned char hdr[4];
+  unsigned char hdr[4] = { 0, 0, 0, 0 }; /* scan-build */
   int res;
 
   if (fread (hdr, sizeof (hdr), 1, h->stream) != 1)
@@ -1561,7 +1567,7 @@ ghw_read_cycle (struct ghw_handler *h)
 int
 ghw_read_dump (struct ghw_handler *h)
 {
-  unsigned char hdr[4];
+  unsigned char hdr[4] = { 0, 0, 0, 0 }; /* scan-build */
   int res;
 
   while (1)
