@@ -628,7 +628,7 @@ if(!(f->flags&(LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))
         }
 
         {
-        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+        struct HistEnt *htemp2 = histent_calloc();
         htemp2->time = -1;
         if(len>1)
                 {
@@ -793,7 +793,7 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 		        }
 
 	        {
-	        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+	        struct HistEnt *htemp2 = histent_calloc();
 	        htemp2->time = -1;
 	        if(len>1)
 	                {
