@@ -109,6 +109,7 @@ GLOBALS->use_full_precision = g_old->use_full_precision;
 GLOBALS->show_base = g_old->show_base;
 GLOBALS->display_grid = g_old->display_grid;
 GLOBALS->disable_mouseover = g_old->disable_mouseover;
+GLOBALS->keep_xz_colors = g_old->keep_xz_colors;
 GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
 GLOBALS->zoom_dyn = g_old->zoom_dyn;
 GLOBALS->zoom_dyne = g_old->zoom_dyne;
@@ -524,6 +525,7 @@ if(!GLOBALS)
 	GLOBALS->constant_marker_update = old_g->constant_marker_update;
 	GLOBALS->convert_to_reals = old_g->convert_to_reals;
 	GLOBALS->disable_mouseover = old_g->disable_mouseover;
+	GLOBALS->keep_xz_colors = old_g->keep_xz_colors;
 	GLOBALS->disable_tooltips = old_g->disable_tooltips;
 	GLOBALS->do_initial_zoom_fit = old_g->do_initial_zoom_fit;
 	GLOBALS->do_resize_signals = old_g->do_resize_signals;
@@ -1461,12 +1463,14 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 		GLOBALS->default_flags=TR_RJUSTIFY;
 		GLOBALS->shift_timebase_default_for_add=LLDescriptor(0);
 		GLOBALS->strace_current_window = 0; /* in case there are shadow traces */
+		GLOBALS->which_t_color = 0;
 	        while((iline=fgetmalloc(wave)))
 	                {
 	                parsewavline(iline, NULL, 0);
 			GLOBALS->strace_ctx->shadow_encountered_parsewavline |= GLOBALS->strace_ctx->shadow_active;
 			free_2(iline);
 	                }
+		GLOBALS->which_t_color = 0;
 		GLOBALS->default_flags=TR_RJUSTIFY;
 		GLOBALS->shift_timebase_default_for_add=LLDescriptor(0);
 
