@@ -53,7 +53,7 @@ void kill_stems_browser(void);
 void kill_stems_browser_single(void *G);
 
 /* prototype only used in main.c */
-void menu_reload_waveform(GtkWidget *widget, gpointer data);
+void menu_reload_waveform_marshal(GtkWidget *widget, gpointer data);
 
 
 /* function for spawning vcd conversions */
