@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -120,6 +120,17 @@ WV_MENU_RFILLOFF,
 WV_MENU_B2G,
 WV_MENU_G2B,
 WV_MENU_GBNONE,
+WV_MENU_CLRFMT0,
+WV_MENU_CLRFMT1,
+WV_MENU_CLRFMT2,
+WV_MENU_CLRFMT3,
+WV_MENU_CLRFMT4,
+WV_MENU_CLRFMT5,
+WV_MENU_CLRFMT6,
+WV_MENU_CLRFMT7,
+WV_MENU_CLRFMTC,
+WV_MENU_SEP5A,
+WV_MENU_KEEPXZ,
 WV_MENU_ESCAH,
 WV_MENU_ESCFH,
 WV_MENU_SEP6,
