@@ -74,7 +74,7 @@ FILE *wave;
 
 if(GLOBALS->filesel_ok)
         {
-        DEBUG(printf("PS Print Fini: %s\n", *fileselbox_text));
+        DEBUG(printf("PS Print Fini: %s\n", *GLOBALS->fileselbox_text));
                 
         if(!(wave=fopen(*GLOBALS->fileselbox_text,"wb")))
                 {
@@ -98,7 +98,7 @@ FILE *wave2;
 
 if(GLOBALS->filesel_ok)
         {
-        DEBUG(printf("PDF Print Fini: %s\n", *fileselbox_text));
+        DEBUG(printf("PDF Print Fini: %s\n", *GLOBALS->fileselbox_text));
                 
         if(!(wave=fopen(*GLOBALS->fileselbox_text,"wb")))
                 {
@@ -157,7 +157,7 @@ FILE *wave;
 
 if(GLOBALS->filesel_ok)
         {
-        DEBUG(printf("MIF Print Fini: %s\n", *fileselbox_text));
+        DEBUG(printf("MIF Print Fini: %s\n", *GLOBALS->fileselbox_text));
                 
         if(!(wave=fopen(*GLOBALS->fileselbox_text,"wb")))
                 {
@@ -378,66 +378,3 @@ void renderbox(char *title)
     gtk_widget_show(GLOBALS->window_renderopt_c_6);
 }
 
-/*
- * $Id: renderopt.c,v 1.11 2009/12/15 23:40:59 gtkwave Exp $
- * $Log: renderopt.c,v $
- * Revision 1.11  2009/12/15 23:40:59  gtkwave
- * removed old style scripts; also removed tempfiles for Tcl args
- *
- * Revision 1.10  2009/05/21 04:04:10  gtkwave
- * crash fixes introduced by ps2pdf addition
- *
- * Revision 1.9  2009/03/31 18:49:49  gtkwave
- * removal of warnings under cygwin compile
- *
- * Revision 1.8  2009/03/29 02:45:41  gtkwave
- * added missing savefile name for pdf (from invocation to invocation)
- *
- * Revision 1.7  2009/03/29 02:08:36  gtkwave
- * added support for PDF file generation via ps2pdf
- *
- * Revision 1.6  2008/06/11 08:01:53  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.5  2007/09/12 17:26:45  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.4  2007/09/10 18:08:49  gtkwave
- * tabs selection can swap dynamically based on external window focus
- *
- * Revision 1.3  2007/08/31 22:42:44  gtkwave
- * 3.1.0 RC3 updates
- *
- * Revision 1.2  2007/08/26 21:35:44  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.8  2007/08/25 19:43:46  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:48  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:23  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:26  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
