@@ -535,7 +535,7 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
   }
   if (t) {			/* we have a signal */
     /* create a list of value change structs (hptrs or vptrs */
-    int nelem = 0, bw = -1 ;
+    int nelem = 0 /* , bw = -1  */ ; /* scan-build */
     TimeType tstart = (dir == STRACE_FORWARD) ? start_time : end_time ;
     TimeType tend = (dir == STRACE_FORWARD) ? end_time : start_time ;
     if ((dir == STRACE_BACKWARD) && (max_elements == 1))
@@ -545,9 +545,11 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
     if (!t->vector) {
       hptr h, h1;
       int len = 0  ;
+      /* scan-build :
       if(t->n.nd->extvals) {
 	bw = abs(t->n.nd->msi - t->n.nd->lsi) + 1 ;
       }
+      */
       h = bsearch_node(t->n.nd, tstart - t->shift) ;
       for(h1 = h; h1; h1 = h1->next) {
 	if (h1->time <= tend) {
@@ -560,8 +562,15 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
 	    if(dir == STRACE_FORWARD)
 	      break ;
 	    else {
+	      if(!l0_head) /* null pointer deref found by scan-build */
+			{
+		        llist_u llp; llp.p = h1;
+		        l_elem = llist_new(llp, LL_VOID_P, -1) ;
+		        l0_head = llist_append(l0_head, l_elem, &l0_tail) ;
+		        if(!l0_tail) l0_tail = l0_head ;
+			}
 	      l_elem = l0_head ;
-	      l0_head = l0_head->next ;
+	      l0_head = l0_head->next ; /* what scan-build flagged as null */
 	      l0_head->prev = NULL ;
 	      l_elem->u.p = (void *)h1 ;
 	      l_elem->next = NULL ;
