@@ -554,9 +554,8 @@ for(GLOBALS->yytext_vcd_c_1[len++]=ch;;GLOBALS->yytext_vcd_c_1[len++]=ch)
         ch=getch();
         if(ch==' ')
                 {
-                signed char ch2;
                 if(match_kw) break;
-                if((ch2 = getch_peek()) == '[')
+                if(getch_peek() == '[')
                         {
                         ch = getch();
                         GLOBALS->varsplit_vcd_c_1=GLOBALS->yytext_vcd_c_1+len;  /* keep looping so we get the *last* one */
@@ -647,14 +646,14 @@ static void sync_end(char *hdr)
 {
 int tok;
 
-if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+if(hdr) { DEBUG(fprintf(stderr,"%s",hdr)); }
 for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1));
+	if(hdr) { DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1)); }
 	}
-if(hdr) DEBUG(fprintf(stderr,"\n"));
+if(hdr) { DEBUG(fprintf(stderr,"\n")); }
 }
 
 static int version_sync_end(char *hdr)
@@ -662,19 +661,19 @@ static int version_sync_end(char *hdr)
 int tok;
 int rc = 0;
 
-if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+if(hdr) { DEBUG(fprintf(stderr,"%s",hdr)); }
 for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1));
+	if(hdr) { DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_c_1)); }
         if(strstr(GLOBALS->yytext_vcd_c_1, "Icarus"))   /* turn off autocoalesce for Icarus */
                 {
                 GLOBALS->autocoalesce = 0;
 		rc = 1;
                 }
 	}
-if(hdr) DEBUG(fprintf(stderr,"\n"));
+if(hdr) { DEBUG(fprintf(stderr,"\n")); }
 return(rc);
 }
 
@@ -1068,7 +1067,7 @@ int disable_autocoalesce = 0;
 
 for(;;)
 	{
-	switch(tok=get_token())
+	switch(get_token())
 		{
 		case T_COMMENT:
 			sync_end("COMMENT:");
@@ -2126,7 +2125,7 @@ struct sym_chain *sym_chain=NULL, *sym_curr=NULL;
 int duphier=0;
 char hashdirty;
 struct vcdsymbol *v, *vprime;
-char *str = NULL;
+char *str = wave_alloca(1); /* quiet scan-build null pointer warning below */
 #ifdef _WAVE_HAVE_JUDY
 int ss_len, longest = 0;
 #endif
@@ -2397,7 +2396,8 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	struct symchain *sc;
                  
         GLOBALS->facs[i]=GLOBALS->curnode->symbol;
-        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+	subst=GLOBALS->facs[i]->name;
+        if((len=strlen(subst))>GLOBALS->longestname) GLOBALS->longestname=len;
 	sc = GLOBALS->curnode;
         GLOBALS->curnode=GLOBALS->curnode->next;
 	free_2(sc);
