@@ -618,7 +618,7 @@ if(!(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
         }
 
 	{
-        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+        struct HistEnt *htemp2 = histent_calloc();
         htemp2->time = -1;
         if(len>1)
         	{
@@ -760,7 +760,7 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 		        }
 
                         {
-                        struct HistEnt *htemp2 = calloc_2(1, sizeof(struct HistEnt));
+                        struct HistEnt *htemp2 = histent_calloc();
                         htemp2->time = -1;
                         if(len>1)
                                 {
